/*
SCRIPT:     	IDA_Primary_Control_Script.do
STATA VERSION: 	Stata 16

This script is designed to build a single IDA dataset from two or more of four
different studies: 
- Americans' Changing Lives (ACL)
- National Longitudinal Study of Adolescent to Adult Health (Add Health)
- Health and Retirement Study (HRS)
- Midlife in the United States (MIDUS)

Four separate Do files have been written, one for each of the four studies. 
The Do files compile a set of harmonized variables across all of the studies.
All four Do files reference global variables that are set in this Do file. There
are four sets of globals that need user attention.


GLOBAL SET #1 - LOG FILE
Set the log file path and name. Every Do file that is called will write into
this file.
(Line 82)


GLOBAL SET #2 - STUDY INCLUSION FLAGS
There is one inclusion flag per study. The default value for each global is 1, 
meaning that the Do file for that study will be run. If you do not have access 
to the data for a particular study, or if you do not wish to include a study, 
change that global to 0.
(Line 91-94)


GLOBAL SET #3 - DIRECTORY PATHS
A global variable has been included for each wave of MIDUS and each wave of Add 
Health (plus other ah studies) to allow users to further organize their files.
For HRS, there is one global variable for each type of data. There is only one 
global for ACL because their data include all waves in one file. Users are 
encouraged to organize all HRS files in a single directory.
If all of your data is in one directory, then the input globals should be the 
same.
 - dofd 	-> Path to your Do files
 - acl  	-> Path to the ACL source data files
 - adh1 	-> Path to the Add Health Wave I source data files
 - adh2 	-> Path to the Add Health Wave II source data files
 - adh3 	-> Path to the Add Health Wave III source data files
 - adh4 	-> Path to the Add Health Wave IV source data files
 - adh5 	-> Path to the Add Health Wave V source data files
 - adhs 	-> Path to the Add Health In-School source data files
 - adhp 	-> Path to the Add Health Parents Survey source data files
 - adhx 	-> Path to the Add Health Constructed source data files
 - hrsr  	-> Path to the HRS Rand source data files
 - hrsf     -> Path to the HRS Fat File source data files
 - hrsc     -> Path to the HRS Childhood source data files
 - hrsb     -> Path to the HRS biomarker source data files
 - mds1 	-> Path to the MIDUS wave 1 source data files
 - mds2 	-> Path to the MIDUS wave 1 source data files
 - mds3    	-> Path to the MIDUS wave 1 source data files
 - mdsmort 	-> Path to the MIDUS core sample mortality data file
 - tmpd 	-> Path to the directory where the interim files will be saved
 - outd 	-> Path to the directory where the final dataset will be saved
(Line 102-126)



GLOBAL SET #4 - FILE NAMES
Global variables have been included for each dataset that is used in the Do 
files. The default filename matches those available from the studies as of 
March 2023. Update these globals to match the names of your files.
Note that file formats are hard-coded into the Do files, so you cannot 
substitute SAS for Stata without editing the code. For example, all Add Health 
datasets used are in SAS XPORT5 format and the Do files utilize the 'import 
sasxport5' command. If you have your Add Health data in Stata format, all of 
those 'import sasxport5' commands will need to be changed to 'use'.
(Lines 134-212)

 
*/

**********************************************************
**                       LOG FILE                       **
**********************************************************
// Start a log file to record every step of all scripts that are called
log using "C:\Work\Logs\IDAlog.txt", replace text



***********************************************************
**                 STUDY INCLUSION FLAGS                 **
***********************************************************
// Study inclusion globals
// Set to 1 to include that study, 0 to exclude
global run_acl = 1		// ACL
global run_adh = 1		// Add Health
global run_hrs = 1		// HRS
global run_mds = 1		// MIDUS



***********************************************************
**                 FILE NAME PATH GLOBALS                **
***********************************************************
// Directory paths
** ACL
global acl   	"C:\Work\Data\Source\ACL"
** ADD HEALTH
global adh1  	"C:\Work\Data\Source\AddHealth\Wave1"
global adh2  	"C:\Work\Data\Source\AddHealth\Wave2"
global adh3  	"C:\Work\Data\Source\AddHealth\Wave3"
global adh4  	"C:\Work\Data\Source\AddHealth\Wave4"
global adh5  	"C:\Work\Data\Source\AddHealth\Wave5"
global adhs  	"C:\Work\Data\Source\AddHealth\Inschool"
global adhp  	"C:\Work\Data\Source\AddHealth\Parents2"
global adhx  	"C:\Work\Data\Source\AddHealth\Constructed"
** HRS
global hrsr   	"C:\Work\Data\Source\HRS\RAND"
global hrsf   	"C:\Work\Data\Source\HRS\FatFiles"
global hrsc   	"C:\Work\Data\Source\HRS\Childhood"
global hrsb   	"C:\Work\Data\Source\HRS\Biomarkers"
** MIDUS
global mds1  	"C:\Work\Data\Source\MIDUS\MIDUS1"
global mds2  	"C:\Work\Data\Source\MIDUS\MIDUS2"
global mds3		"C:\Work\Data\Source\MIDUS\MIDUS3"
global mdsmort 	"C:\Work\Data\Source\MIDUS\MIDUS_Mortality"
** OTHER
global dofd  	"C:\Work\Code"
global tmpd  	"C:\Work\Data\Interim"
global outd  	"C:\Work\Data\Final"



***********************************************************
**                   FILE NAME GLOBALS                   **
***********************************************************
// File names
** ACL
global facl		"04690-0001-Data.dta"	// ACL All Waves
** ADD HEALTH
*--- Survey Waves
global fah1		"allwave1.xpt"			// Add Health (AH) Wave I
global fah2		"wave2.xpt"				// AH Wave II
global fah3		"wave3.xpt"				// AH Wave III
global fah3s17	"sect17.xpt"			// AH Wave III Section 17
global fah3s19	"sect19.xpt"			// AH Wave III Section 19
global fah4		"wave4.xpt"				// AH Wave IV
global fah5		"wave5.xpt"				// AH Wave V
*--- Biomarker Data
global fah4crp	"crp_ebv.xpt"			// AH Wave IV Inflammation/Immune Function
global fah4glu	"glu_a1c.xpt"			// AH Wave IV Glucose Homeostasis
global fah4lpd	"lipids.xpt"			// AH Wave IV Lipids
global fah5anth	"banthro5.xpt"			// AH Wave V Anthropometrics
global fah5card	"bcardio5.xpt"			// AH Wave V Cardiovascular Measures
global fah5crp	"bcrp5.xpt"				// AH Wave V Inflammation/Immune Function
global fah5glu	"bglua1c5.xpt"			// AH Wave V Glucose Homeostasis
global fah5lpd	"blipids5.xpt"			// AH Wave V Lipids
global fah5rnl	"brenal5.xpt"			// AH Wave V Renal Function
*--- Disposition Data
global fahdsp12	"w1w2dsp.xpt"			// AH Waves I & II Disposition Data
global fahdsp3	"dsp3.xpt"				// AH Wave III Disposition Data
global fahdsp4	"dsp4.xpt"				// AH Wave IV Disposition Data
global fahdsp5	"dsp5.xpt"				// AH Wave V Disposition Data
*--- Weights
global fah1wght	"Homewt1.xpt"			// AH Wave I In-Home Weight Components
global fah2wght	"Homewt2.xpt"			// AH Wave II In-Home Weight Components
global fah3wght	"weights3.xpt"			// AH Wave III Weights
global fah4wght	"weights4.xpt"			// AH Wave IV Weights
global fah5wght	"weights5.xpt"			// AH Wave V Weights
*--- Additional Studies, Surveys, and Contextual Datasets
global fahses	"conses.xpt"			// AH Constructed SES
global fahpar	"parent2.xpt"			// AH Parents 2015-2017
global fahcrl	"currel.xpt"			// AH Current Relationship Status
global fahsch	"Inschool.xpt"			// AH In School Survey
global fahnet	"network.xpt"			// AH Wave I School Network
global fah3reg	"w3region.xpt"			// AH Wave III Census Region
global fah4reg	"w4region.xpt"			// AH Wave IV Census Region
** HRS
*--- Rand Files (Longitudinal and Family)
global fhrsrlf	"randhrs1992_2018v2.dta" // Rand HRS Longitudinal File 1992-2018 V2
global fhrsrfam	"randhrsfamr1992_2014v1.dta" // Rand HRS Family Data 2014 V1
*--- Fat Files
global fhrsff96	"h96f4a.dta"			// HRS Fat File 1996
global fhrsff98	"hd98f2c.dta"			// HRS Fat File 1998
global fhrsff00	"h00f1d.dta"			// HRS Fat File 2000
global fhrsff02	"h02f2c.dta"			// HRS Fat File 2002
global fhrsff04	"h04f1c.dta"			// HRS Fat File 2004
global fhrsff06	"h06f4a.dta"			// HRS Fat File 2006
global fhrsff08	"h08f3a.dta"			// HRS Fat File 2008
global fhrsff10	"hd10f6a.dta"			// HRS Fat File 2010
global fhrsff12	"h12f3a.dta"			// HRS Fat File 2012
global fhrsff14	"h14f2b.dta"			// HRS Fat File 2014
global fhrsff16	"h16f2b.dta"			// HRS Fat File 2016
global fhrsff18	"h18f2a.dta"			// HRS Fat File 2018
*--- Biomarkers
global fhrsb06	"biomk06bl_r.sas7bdat"	// HRS Biomarker Data 2006
global fhrsb08	"biomk08bl_r.sas7bdat"	// HRS Biomarker Data 2008
global fhrsb10	"biomk10bl_r.sas7bdat"	// HRS Biomarker Data 2010
global fhrsb12	"biomk12bl_r.sas7bdat"	// HRS Biomarker Data 2012
global fhrsb14	"biomk14bl.sas7bdat"	// HRS Biomarker Data 2014
global fhrsb16	"biomk16bl_r.sas7bdat"	// HRS Biomarker Data 2016
global fhrsv16	"hrs2016vbs.sas7bdat"	// HRS Venous Blood Study 2016
*--- Childhood SES
global fhrscses	"cses_measures.dta"		// HRS Childhood Socio-Economic Status
** MIDUS
*--- Main Survey Files
global fmds1	"02760-0001-Data.dta"	// MIDUS 1 Main Survey Data
global fmds2	"04652-0001-Data.dta"	// MIDUS 2 Main Survey Data
global fmds3	"36346-0001-Data.dta"	// MIDUS 3 Main Survey Data
*--- Biomarker, Cognition, Disposition, Mortality Files
global fmds2bio	"29282-0001-Data.dta"	// MIDUS 2 Biomarkers
global fmds2cog	"25281-0001-Data.dta"	// MIDUS 2 Cognition
global fmds3cog	"37095-0001-Data.dta"	// MIDUS 3 Cognition
global fmds2dsp	"04652-0002-Data.dta"	// MIDUS 2 Disposition Codes
global fmds3dsp	"36346-0002-Data.dta"	// MIDUS 3 Disposition Codes
global fmdsmort	"37237-0001-Data.dta"	// MIDUS Core Sample Mortality



***********************************************************
**      RUN STUDY DO FILES BASED ON INCLUSION FLAGS      **
***********************************************************
// Run all of the Do files to generate the category datasets
if $run_acl == 1 {
	do "$dofd\IDA_Secondary_Study_Variables_ACL.do"
}

if $run_adh == 1 {
	do "$dofd\IDA_Secondary_Study_Variables_AddHealth.do"
}

if $run_hrs == 1 {
	do "$dofd\IDA_Secondary_Study_Variables_HRS.do"
}

if $run_mds == 1 {
	do "$dofd\IDA_Secondary_Study_Variables_MIDUS.do"
}



***********************************************************
**     APPEND STUDY DATASETS BASED ON INCLUSION FLAGS    **
***********************************************************
// Sum the globals
global run_sum = $run_acl + $run_adh + $run_hrs + $run_mds

// Append outputs based on inclusion flags
if $run_sum == 4 {
	// All four datasets
	use "$tmpd\master_vars_acl.dta", clear
	append using "$tmpd\master_vars_addhealth.dta"
	append using "$tmpd\master_vars_hrs.dta"
	append using "$tmpd\master_vars_midus.dta"
}
else if $run_sum == 3 {
	// Only three datasets
	if $run_acl == 1 {
		// Start with ACL
		use "$tmpd\master_vars_acl.dta", clear
		if $run_adh == 1 {
			// Append Add Health
			append using "$tmpd\master_vars_addhealth.dta"
			if $run_hrs == 1 {
				// Append HRS
				append using "$tmpd\master_vars_hrs.dta"
				** DONE - ACL, Add Health, HRS
			}
			else {
				// Append MIDUS
				append using "$tmpd\master_vars_midus.dta"
				** DONE - ACL, Add Health, MIDUS
			}
		}
		else {
			// Not Add Health, so append HRS and MIDUS
			append using "$tmpd\master_vars_hrs.dta"
			append using "$tmpd\master_vars_midus.dta"
			** DONE - ACL, HRS, MIDUS
		}
	}
	else {
		// Not ACL, so use the other three datasets
		use "$tmpd\master_vars_addhealth.dta", clear
		append using "$tmpd\master_vars_hrs.dta"
		append using "$tmpd\master_vars_midus.dta"
		** DONE - Add Health, HRS, MIDUS
	}
}
else if $run_sum == 2 {
	// Only two datasets
	if $run_acl == 1 {
		// Start with ACL
		use "$tmpd\master_vars_acl.dta", clear
		if $run_adh == 1 {
			// Append Add Health
			append using "$tmpd\master_vars_addhealth.dta"
			** DONE - ACL and Add Health
		}
		else if $run_hrs == 1 {
			// Append HRS
			append using "$tmpd\master_vars_hrs.dta"
			** DONE - ACL and HRS
		}
		else {
			// Append MIDUS
			append using "$tmpd\master_vars_midus.dta"
			** DONE - ACL and MIDUS
		}
	}
	else if $run_adh == 1 {
		// Start with Add Health
		use "$tmpd\master_vars_addhealth.dta", clear
		if $run_hrs == 1 {
			// Append HRS
			append using "$tmpd\master_vars_hrs.dta"
			** DONE - Add Health and HRS
		}
		else {
			// Append MIDUS
			append using "$tmpd\master_vars_midus.dta"
			** DONE - Add Health and MIDUS
		}
	}
	else {
		// Start with HRS and append MIDUS
		use "$tmpd\master_vars_hrs.dta", clear
		append using "$tmpd\master_vars_midus.dta"
		** DONE - HRS and MIDUS
	}
}
else {
	// Only one study flagged for inclusion, so no need to continue script
	di "You only chose one dataset!"
}



***********************************************************
**           REORDER THE VARIABLES DYNAMICALLY           **
***********************************************************
// Set local with variables in the desired order
local vlist "id study wave year_died attrition died year_died month_died date_died death_source death2intvw_months f_sei m_sei fempl mempl pempl p_empl_ft p1_educ p2_educ childses phhincome pincome pwelfare rassets_10k rassets_20k rassets_50k rassets_100k rassets_200k rassets_500k rassets_total rassets_status rassets_owe reduc_year reduc_8yr reduc_cat reduc_GED reduc_HS reduc_AA reduc_BA reduc_MA reduc_PhD reduc_prof reduc_current rincome_cat rincome_hh rincome_period rincome_total rincome_wagefreq rincome_wages rincome_wagescat rses_4cat meeting_all religious_attend volunteer_religion volunteer_edu volunteer_politics volunteer_seniors volunteer_other volunteerhrs close_other_talk close_other_inperson close_other_loved close_other_demand close_other_listen close_other_critical child_contact child_listen child_feel_loved child_demand child_critic mom_contact dad_contact biomom_alive biodad_alive marital_status sppn_listen sppn_loved sppn_demand sppn_critic child_num child_contact1 child_contact2 biomom_died biodad_died child_nonhh child_hh par_died1 par_died2 par_died3 sch_close sch_feel_part sch_happy fam_understand fam_attention fam_fun resmom_activities_shop resmom_activities_sport resmom_activities_religion resmom_activities_dating resmom_activities_movie resmom_activities_problem resmom_activities_argument resmom_activities_grades resmom_activities_project resmom_activities_sch resmom_activities_none resdad_activities_shop resdad_activities_sport resdad_activities_religion resdad_activities_dating resdad_activities_movie resdad_activities_problem resdad_activities_argument resdad_activities_grades resdad_activities_project resdad_activities_sch resdad_activities_none mom_warm dad_warm mom_close dad_close mom_relationship dad_relationship mom_comm dad_comm par_care fri_contact fri_care volunteer relationship_current dating_3months rel_start_date interview_date child_close child_overwhelm child_stress sppn_rel_sat fri_num fam_rely fam_open fam_demand_critic child_bio_num child_nonbio_num child_open child_rely child_demand_critic sppn_open sppn_rely sppn_demand_critic fri_rely fri_open fri_demand_critic sch_activity1 sch_activity2 sch_activity3 sch_activity4 sch_activity5 sch_activity6 sch_activity7 sch_activity8 sch_activity9 sch_activity10 sch_activity11 sch_activity12 sch_activity13 sch_activity14 sch_activity15 sch_activity16 sch_activity17 sch_activity18 sch_activity19 sch_activity20 sch_activity21 sch_activity22 sch_activity23 sch_activity24 sch_activity25 sch_activity26 sch_activity27 sch_activity28 sch_activity29 sch_activity30 sch_activity31 sch_activity32 sch_activity33 sch_activity_none fri_indegree fri_outdegree neigh_contact_per child_res mom_res dad_res par_alive fam_demand fam_critic fam_letudown fam_nerves child_contact_inperson child_contact_phone child_contact_write child_understand child_letudown child_nerves cohabitation cohabitating sppn_rel_close sppn_understand sppn_letudown sppn_nerves fri_yesno fri_contact_inperson fri_contact_phone fri_contact_write fri_understand fri_demand fri_critic fri_letudown fri_nerves meeting_soc meeting_other meeting_prof neigh_contact_any neigh_contact volunteerhrs_hos volunteerhrs_edu volunteerhrs_politics volunteerhrs_other fam_contact fam_care sppn_care sppn_appreciates sppn_be_yourself sppn_tense sppn_argue married_cohab height weight bmi bmi_class wc wc_class bp_class systolicbp diastolicbp hypertension meanarterpres totchol highchol hdlchol ldlchol ldl_class diabetes fastgluc fastgluc_class nonfastgluc_class hba1c hba1c_class pulse pulsepress crp crp_class cystatinc renalfunction triglyceride triglyceride_class inflam_med lipid_med diab_med hyperten_med rmem_datec rmem_dwkc rmem_month rmem_day rmem_yr rmem_dwk rmem_mmn rmem_currp rmem_prevp rmem_1 rmem2 rmem3 rmem4 rmem5 rmem6 r_vf1 r_vf2 r_vf3 r_vf4 r_vf5 r_vf6 rmem_date rmem_sum rmem_ser3a rmem_ser3b rmem_ser3c rmem_ser3d rmem_ser3e rmem_ser3f rmem_ser3sum rmem_proxy1 rmem_proxy2 rmem_proxy3 rmem_proxy4 rmem_proxy5a rmem_proxy5b rmem_proxy5c rmem_proxy5d rmem_proxy5e rmem_proxy5f rmem_correct rmem_recall1 rmem_recall2 rmem_recall3 rmem_recall4 rmem_recall5 rmem_recall6 rmem_recall7 rmem_recall8 rmem_recall9 rmem_recall10 rmem_recallassist rcog_5item rcog_6item immedrecall delayrecall digbackwards serial7 backcount datename_mo datename_daymo datename_year datename_daywk objname_scis objname_cact presname vpname vocab cogtot numseries catflu sgstsingle sgstswitch btact physactivity physactivity_quartile hrsexercise pa_light pa_light3xwk pa_mod pa_mod_wk pa_vig pa_vig_wk pa_vig3xwk pa_teamsports_wk pa_indvsports_wk pa_gymtraining_wk pa_walking_wk fitnesscenter summerpa_mod summerpa_vig winterpa_mod winterpa_vig summerleisure_light summerleisure_mod summerleisure_vig winterleisure_light winterleisure_mod winterleisure_vig summerchore_light summerchore_mod summerchore_vig winterchore_light winterchore_mod winterchore_vig fastfood ssb everdrink alc_drinkfreqweek num_drinksday bingedrinking daysdrinkpermonth lownum_drinks highnum_drinks mednum_drinks drinksperday smoker eversmoke_reg dailysmokefreq age birthyear hrscohort female race race_onecat race_wh race_aa race_as race_ai race_pi race_ot hispanic immigrant religion language region proxy pvt verbal_iq adult_srh child_srh healthins anxiety depressiondx depressed_cesd anxiety_depression jobstress misswork_healthprob healthins_medicarepta healthins_medicareptb healthins_medicareptd healthins_medicaid healthins_va healthins_employer healthins_self employhealthins govhealthins relaxprobs pss_1 pss_2 pss_3 pss_4 adl iadl comorbidities limit_pen limit_reach limit_stand limit_grip limit_steps limit_dressing limit_eating limit_toilet limit_shopping limit_mod_act limit_vig_act limit_stairs limit_sev_stairs limit_flight_stairs limit_bending limit_walking limit_sev_blocks limit_one_block limit_groceries limit_bath_dress limit_walk_one_block limit_walk_block limit_walk_mile limit_bathing limit_housework lbelig xsectionweight acl_panelweight ah_longweight ah_longweight34 ah_longweight345 ah_longweight45 ah_psu hrs_sampleweight hrs_strataweight"
local i = 1
// Step through the variable list and rename sequentially if the variable exists
foreach v of local vlist {
	local j = string(`i', "%03.0f")
	capture confirm variable `v', exact
	if !_rc {
		rename `v' x`j'_`v'
	}
	local i = `i' + 1
}
// Order alphanumerically
order *, alpha
// Drop the first five characters that were added in the loop above
renvars x*, pred(5)



***********************************************************

// Label the dataset
la data "IDA Master Dataset"

// Save as the final dataset
save "$outd\Master_IDA_Dataset.dta", replace

log close